==> pim-sieve-editor-18.07.90.tar.xz: pim-sieve-editor-18.07.90/src/importwizard/autotests/importimapsettingnofoundpagetest.cpp <==
/*
   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "importimapsettingnofoundpagetest.h"
#include "../importimapsettingnofoundpage.h"
#include <QLabel>
#include <QTest>
#include <QVBoxLayout>

ImportImapSettingNoFoundPageTest::ImportImapSettingNoFoundPageTest(QObject *parent)
    : QObject(parent)
{
}

ImportImapSettingNoFoundPageTest::~ImportImapSettingNoFoundPageTest()
{
}

void ImportImapSettingNoFoundPageTest::shouldHaveDefaultValue()
{
    ImportImapSettingNoFoundPage w;
    QLabel *lab = w.findChild<QLabel *>(QStringLiteral("label"));
    QVERIFY(lab);
    QVERIFY(!lab->text().isEmpty());

    QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
    QVERIFY(mainLayout);
    QCOMPARE(mainLayout->margin(), 0);
}

QTEST_MAIN(ImportImapSettingNoFoundPageTest)

==> pim-sieve-editor-19.03.80.tar.xz: pim-sieve-editor-19.03.80/src/importwizard/autotests/importimapsettingnofoundpagetest.cpp <==
/*
   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "importimapsettingnofoundpagetest.h"
#include "../importimapsettingnofoundpage.h"
#include "kdepimtest_layout.h"
#include <QLabel>
#include <QTest>
#include <QVBoxLayout>

ImportImapSettingNoFoundPageTest::ImportImapSettingNoFoundPageTest(QObject *parent)
    : QObject(parent)
{
}

ImportImapSettingNoFoundPageTest::~ImportImapSettingNoFoundPageTest()
{
}

void ImportImapSettingNoFoundPageTest::shouldHaveDefaultValue()
{
    ImportImapSettingNoFoundPage w;
    QLabel *lab = w.findChild<QLabel *>(QStringLiteral("label"));
    QVERIFY(lab);
    QVERIFY(!lab->text().isEmpty());

    QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainlayout"));
    QVERIFY(mainLayout);
    KdepimTestLayout::checkContentsMargins(0, mainLayout);
}

QTEST_MAIN(ImportImapSettingNoFoundPageTest)
